/*
 * Copyright 2017 Arne Vajhj.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

package dk.vajhoej.vms.web;

/**
 * Class Result contain all information for response.
 */
public class Result {
	private boolean status;
	private String errorMessage;
	private String contentType;
	private byte[] contentBody;
	/**
	 * Construct instance.
	 * @param status status code
	 * @param errorMessage error message
	 * @param contentType content type aka MIME type
	 * @param contentBody content body
	 */
	public Result(boolean status, String errorMessage, String contentType, byte[] contentBody) {
		this.status = status;
		this.errorMessage = errorMessage;
		this.contentType = contentType;
		this.contentBody = contentBody;
	}
	/**
	 * Get status code.
	 * @return status code.
	 */
	public boolean isStatus() {
		return status;
	}
	/**
	 * Get error message.
	 * @return error message
	 */
	public String getErrorMessage() {
		return errorMessage;
	}
	/**
	 * Get content type aka MIME type.
	 * @return content type
	 */
	public String getContentType() {
		return contentType;
	}
	/**
	 * Get content body.
	 * @return content body
	 */
	public byte[] getContentBody() {
		return contentBody;
	}
}
