/*
 * Copyright 2017 Arne Vajhj.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

package dk.vajhoej.vms.web.api;

import java.io.UnsupportedEncodingException;

import dk.vajhoej.vms.web.FunctionModule;
import dk.vajhoej.vms.web.Result;

/**
 * Class ApiModule forward request to plugins implementing API.
 */
public abstract class ApiModule implements FunctionModule {
	public abstract String getContext();
	public abstract String getMimeType();
	protected abstract byte[] serialize(Object o) throws UnsupportedEncodingException;
	public Result getResponse(String remurl, String query) {
		try {
			Plugin p = (Plugin)Class.forName(remurl.substring(1)).newInstance();
			Object o = p.get(query);
			return new Result(true, null, getMimeType(), serialize(o));
		} catch (Exception e) {
			return new Result(false, e.getClass().getName() + ":" + e.getMessage(), null, null);
		}
	}
}
