/*
 * Copyright 2017 Arne Vajhj.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

package dk.vajhoej.vms.web.https;

import org.eclipse.jetty.server.Connector;
import org.eclipse.jetty.server.ssl.SslSelectChannelConnector;
import org.eclipse.jetty.util.ssl.SslContextFactory;

import dk.vajhoej.vms.web.http.HttpModule;

/**
 * Class HttpsModule implements HTTPS protocol.
 */
public class HttpsModule extends HttpModule {
	private String jkspath;
	private String password;
	public HttpsModule(int port, String jkspath, String password) {
		super(port);
		this.jkspath = jkspath;
		this.password = password;
	}
	protected boolean isLoginValid() {
		return true;
	}
	protected Connector getConnector(int port) {
        SslContextFactory sslctx = new SslContextFactory();
        sslctx.setKeyStorePath(jkspath);
        sslctx.setKeyStorePassword(password);
        sslctx.setIncludeProtocols("TLSv1.1", "TLSv1.2");
		Connector con = new SslSelectChannelConnector(sslctx);
		con.setPort(port);
		return con;
	}
}
